package federe;

import java.io.*;
import java.net.*;


import message.*;
/**<p><code>FedereBasic</code> is a federate that is going to communicate with a RTIA on port number 2000. It will send requests to create a federation, to join it, to resign from it and to destroy it.</p>
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
*/
public class FedereBasic {
	private MessageBuffer msgbuff;
	private ServerSocket ssocket;
	private Socket socket;
	private Process rtia;
	private InputStream in;
	private static int nb_essais = 4;
	
	public FedereBasic() throws IOException{
		this.msgbuff = new MessageBuffer();
		this.ssocket = new ServerSocket(2000); //We create a server socket on port number 2000
		
		/*String[] command = { "cmd.exe", "/C", "java -classpath . federe.RTIAFake >fichier.txt"};
		Runtime runtime = Runtime.getRuntime();
		rtia = runtime.exec(command);*/
		
		this.socket = ssocket.accept(); //We wait that the RTIA is connected on this port
		System.out.println("Connexion du federe sur le port " + this.socket.getLocalPort());
		
		this.in = this.socket.getInputStream();
		in.read(); //We read the byte (5) send by the RTIA
		System.out.println("Confirmation de connexion du RTIA");
	}
	
	private void createFederation() throws IOException, InterruptedException{
		boolean AR = false;
		int compteur = 0;
		
		while ((AR == false)&&(compteur<nb_essais)){
			//We send the message Create_Federation_Execution to the RTIA with the socket
			Message msg = new MSG_Create_Federation_Execution(message.Exception.e_NO_EXCEPTION, new FederationTime(), "Federation Toto", "toto");
			msg.writeObject(this.msgbuff);
			System.out.println("Envoi du message de creation de federation");
			this.msgbuff.send(this.socket.getOutputStream());
		
			//We listen on the same socket and we deserialize the message
			this.in = this.socket.getInputStream();
			msg = this.msgbuff.deserealize(in);
			System.out.println("Reception d'un accuse de reception :");
			System.out.println(msg.toString() + "\n");
			//If the feedback is the correct one, we move on next step
			if (msg.getType() == Type.CREATE_FEDERATION_EXECUTION){
				AR = true;
			} else {
				System.out.println("Mauvais accuse de reception");
			}
			Thread.sleep(5000);
		}
		//this.attendre();
	}
	
	private void joinFederation() throws IOException, InterruptedException{
		boolean AR = false;
		int compteur = 0;
		
		while ((AR == false)&&(compteur<nb_essais)){
			compteur++;
			//Message msg = new MSG_Join_Federation_Execution(message.Exception.e_NO_EXCEPTION, new FederationTime(), (short) 0, "Federation Toto", "toto");
			Message msg = new MSG_Join_Federation_Execution();
			msg.writeObject(this.msgbuff);
			System.out.println("Envoi du message d'adhesion a la federation");
			this.msgbuff.send(this.socket.getOutputStream());

			this.in = this.socket.getInputStream();
			msg = this.msgbuff.deserealize(in);
			System.out.println("Reception d'un accuse de reception :");
			System.out.println(msg.toString() + "\n");
			if (msg.getType() == Type.JOIN_FEDERATION_EXECUTION){
				AR = true;
			} else {
				System.out.println("Mauvais accuse de reception");
			}
			Thread.sleep(5000);
		}
		//this.attendre();
	}
	
	private void resignFederation()throws IOException, InterruptedException{
		boolean AR = false;
		int compteur = 0;
		
		while ((AR == false)&&(compteur<nb_essais)){
			compteur++;
			Message msg = new MSG_Resign_Federation_Execution();
			msg.writeObject(this.msgbuff);
			System.out.println("Envoi du message de desinscription a la federation");
			this.msgbuff.send(this.socket.getOutputStream());

			this.in = this.socket.getInputStream();
			msg = this.msgbuff.deserealize(in);
			System.out.println("Reception d'un accuse de reception :");
			System.out.println(msg.toString() + "\n");
			if (msg.getType() == Type.RESIGN_FEDERATION_EXECUTION){
				AR = true;
			} else {
				System.out.println("Mauvais accuse de reception");
			}
			Thread.sleep(5000);
		}
		//this.attendre();
	}
	
	private void destroyFederation() throws IOException, InterruptedException{
		boolean AR = false;
		int compteur = 0;
		
		while ((AR == false)&&(compteur<nb_essais)){
			compteur++;
			Message msg = new MSG_Destroy_Federation_Execution(message.Exception.e_NO_EXCEPTION, new FederationTime(), "Federation Toto");
			msg.writeObject(this.msgbuff);
			System.out.println("Envoi du message de destruction de federation");
			this.msgbuff.send(this.socket.getOutputStream());
		
			this.in = this.socket.getInputStream();
			msg = this.msgbuff.deserealize(in);
			System.out.println("Reception d'un accuse de reception :");
			System.out.println(msg.toString() + "\n");
			if (msg.getType() == Type.DESTROY_FEDERATION_EXECUTION){
				AR = true;
			}
			Thread.sleep(5000);
			//this.attendre();
		}
	}
	
	private void attendre() throws IOException, InterruptedException{
		System.out.println("Appuyer sur Entree pour continuer");
		boolean character = false;
		while (character == false) {
			InputStreamReader instream = new InputStreamReader(System.in);
			BufferedReader inreader = new BufferedReader(instream);
			int c = inreader.read();
			if (c == 13) {
				character = true;
			} else {
				System.out.println("Mauvais accuse de reception");
			}
			Thread.sleep(500);
		}
		//this.attendre();
	}
	
	public static final void main(final String[] args) throws IOException, InterruptedException {
		FedereBasic fed = new FedereBasic();
		fed.attendre();
		fed.createFederation();
		fed.joinFederation();
		fed.resignFederation();
		fed.destroyFederation();
		
		System.out.println("Fermeture de la socket federe");
		fed.socket.close();
		fed.ssocket.close();
		System.out.println("Destruction du RTIA");
		//fed.rtia.destroy();
    }
}
