package message;

import java.util.HashMap;

/**
* <p><code>Exception</code> represents the exception carried by the messages which is exchanged between the federate and the RTIA.</p>
*
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
*/
public enum Exception {
	
	e_NO_EXCEPTION,
	e_ArrayIndexOutOfBounds,
    e_AsynchronousDeliveryAlreadyEnabled,
    e_AsynchronousDeliveryAlreadyDisabled,
    e_AttributeAlreadyOwned,
    e_AttributeAlreadyBeingAcquired,
    e_AttributeAlreadyBeingDivested,
    e_AttributeAcquisitionWasNotRequested,
    e_AttributeDivestitureWasNotRequested,
    e_AttributeNotDefined,
    e_AttributeNotKnown,
    e_AttributeNotOwned,
    e_AttributeNotPublished,
    e_AttributeNotSubscribed,
    e_ConcurrentAccessAttempted,
    e_CouldNotDiscover,
    e_CouldNotOpenRID,
    e_CouldNotOpenFED,
    e_CouldNotRestore,
    e_DeletePrivilegeNotHeld,
    e_ErrorReadingRID,
    e_ErrorReadingFED,
    e_EventNotKnown,
    e_FederateAlreadyPaused,
    e_FederateAlreadyExecutionMember,
    e_FederateDoesNotExist,
    e_FederateInternalError,
    e_FederateNameAlreadyInUse,
    e_FederateNotExecutionMember,
    e_FederateNotPaused,
    e_FederateNotPublishing,
    e_FederateNotSubscribing,
    e_FederateOwnsAttributes,
    e_FederatesCurrentlyJoined,
    e_FederateWasNotAskedToReleaseAttribute,
    e_FederationAlreadyPaused,
    e_FederationExecutionAlreadyExists,
    e_FederationExecutionDoesNotExist,
    e_FederationNotPaused,
    e_FederationTimeAlreadyPassed,
    e_RegionNotKnown,
    e_IDsupplyExhausted,
    e_InteractionClassNotDefined,
    e_InteractionClassNotKnown,
    e_InteractionClassNotPublished,
    e_InteractionParameterNotDefined,
    e_InteractionParameterNotKnown,
    e_InvalidDivestitureCondition,
    e_InvalidExtents,
    e_InvalidFederationTime,
    e_InvalidFederationTimeDelta,
    e_InvalidObjectHandle,
    e_InvalidOrderType,
    e_InvalidResignAction,
    e_InvalidRetractionHandle,
    e_InvalidRoutingSpace,
    e_InvalidTransportType,
    e_MemoryExhausted,
    e_NameNotFound,
    e_NoPauseRequested,
    e_NoResumeRequested,
    e_ObjectClassNotDefined,
    e_ObjectClassNotKnown,
    e_ObjectClassNotPublished,
    e_ObjectClassNotSubscribed,
    e_ObjectNotKnown,
    e_ObjectAlreadyRegistered,
    e_RestoreInProgress,
    e_RestoreNotRequested,
    e_RTICannotRestore,
    e_RTIinternalError,
    e_SpaceNotDefined,
    e_SaveInProgress,
    e_SaveNotInitiated,
    e_SecurityError,
    e_SpecifiedSaveLabelDoesNotExist,
    e_TimeAdvanceAlreadyInProgress,
    e_TimeAdvanceWasNotInProgress,
    e_TooManyIDsRequested,
    e_UnableToPerformSave,
    e_UnimplementedService,
    e_UnknownLabel,
    e_ValueCountExceeded,
    e_ValueLengthExceeded;

	/**<p>Makes a HashMap between the <code>int</code> which corresponds with the <code>Exception</code> and the <code>Exception</code> itself.</p>
	 * <p>For instance, <code>Exception.reverse.get(0)</code> will return the <code>Exception</code> e_NO_EXCEPTION.</p>
	 */
	public static HashMap<Integer,Exception> reverse = new HashMap<Integer,Exception> ();

    static {
        for (Exception m : Exception.values()) {
            reverse.put(m.ordinal(), m);
        }
    }
	
    /**Returns the <code>int</code> which corresponds with the <code>Exception</code>.
	 * @return the <code>int</code>
	 */
	public int getException() {
		return this.ordinal();
	}
}
