package message;

import java.util.HashMap;

/**
* <p><code>Type</code> represents the type of the messages which is exchanged between the federate and the RTIA.
* The type of the message is a request from the Java federate or from the RTIA for the other one.</p>
*
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
*/
public enum Type {
	
	NOT_USED,

	// gestion federation
    CREATE_FEDERATION_EXECUTION,
    DESTROY_FEDERATION_EXECUTION,
    JOIN_FEDERATION_EXECUTION,
    RESIGN_FEDERATION_EXECUTION,
    REGISTER_FEDERATION_SYNCHRONIZATION_POINT,
    SYNCHRONIZATION_POINT_REGISTRATION_FAILED,
    SYNCHRONIZATION_POINT_REGISTRATION_SUCCEEDED,
    ANNOUNCE_SYNCHRONIZATION_POINT,
    SYNCHRONIZATION_POINT_ACHIEVED,
    FEDERATION_SYNCHRONIZED,
    REQUEST_FEDERATION_SAVE,
    INITIATE_FEDERATE_SAVE,
    FEDERATE_SAVE_BEGUN,
    FEDERATE_SAVE_COMPLETE,
    FEDERATE_SAVE_NOT_COMPLETE,
    FEDERATION_SAVED,
    FEDERATION_NOT_SAVED,
    REQUEST_FEDERATION_RESTORE,
    REQUEST_FEDERATION_RESTORE_FAILED,
    REQUEST_FEDERATION_RESTORE_SUCCEEDED,
    INITIATE_FEDERATE_RESTORE,
    FEDERATE_RESTORE_COMPLETE,
    FEDERATE_RESTORE_NOT_COMPLETE,
    FEDERATION_RESTORED,
    FEDERATION_NOT_RESTORED,
    FEDERATION_RESTORE_BEGUN,

    // Declaration
    PUBLISH_OBJECT_CLASS,
    UNPUBLISH_OBJECT_CLASS,
    PUBLISH_INTERACTION_CLASS,
    UNPUBLISH_INTERACTION_CLASS,
    SUBSCRIBE_OBJECT_CLASS_ATTRIBUTES,
    UNSUBSCRIBE_OBJECT_CLASS,
    SUBSCRIBE_INTERACTION_CLASS,
    UNSUBSCRIBE_INTERACTION_CLASS,
    START_REGISTRATION_FOR_OBJECT_CLASS,
    STOP_REGISTRATION_FOR_OBJECT_CLASS,
    TURN_INTERACTIONS_ON,
    TURN_INTERACTIONS_OFF,

    // Object
    REGISTER_OBJECT_INSTANCE,
    UPDATE_ATTRIBUTE_VALUES,
    DISCOVER_OBJECT_INSTANCE,
    REFLECT_ATTRIBUTE_VALUES,
    SEND_INTERACTION,
    RECEIVE_INTERACTION,
    DELETE_OBJECT_INSTANCE,
    LOCAL_DELETE_OBJECT_INSTANCE,
    REMOVE_OBJECT_INSTANCE,
    CHANGE_ATTRIBUTE_TRANSPORTATION_TYPE,
    CHANGE_INTERACTION_TRANSPORTATION_TYPE,
    REQUEST_OBJECT_ATTRIBUTE_VALUE_UPDATE,
    REQUEST_CLASS_ATTRIBUTE_VALUE_UPDATE,
    PROVIDE_ATTRIBUTE_VALUE_UPDATE,
    ATTRIBUTES_IN_SCOPE,
    ATTRIBUTES_OUT_OF_SCOPE,
    TURN_UPDATES_ON_FOR_OBJECT_INSTANCE,
    TURN_UPDATES_OFF_FOR_OBJECT_INSTANCE,

    // Ownership
    REQUEST_ATTRIBUTE_OWNERSHIP_DIVESTITURE,
    REQUEST_ATTRIBUTE_OWNERSHIP_ASSUMPTION,
    NEGOTIATED_ATTRIBUTE_OWNERSHIP_DIVESTITURE,
    ATTRIBUTE_OWNERSHIP_DIVESTITURE_NOTIFICATION,
    ATTRIBUTE_OWNERSHIP_ACQUISITION_NOTIFICATION,
    REQUEST_ATTRIBUTE_OWNERSHIP_ACQUISITION,
    REQUEST_ATTRIBUTE_OWNERSHIP_RELEASE,
    QUERY_ATTRIBUTE_OWNERSHIP,
    INFORM_ATTRIBUTE_OWNERSHIP,
    IS_ATTRIBUTE_OWNED_BY_FEDERATE,
    ATTRIBUTE_IS_NOT_OWNED,
    ATTRIBUTE_OWNED_BY_RTI,
    ATTRIBUTE_OWNERSHIP_ACQUISITION_IF_AVAILABLE,
    ATTRIBUTE_OWNERSHIP_UNAVAILABLE,
    UNCONDITIONAL_ATTRIBUTE_OWNERSHIP_DIVESTITURE,
    ATTRIBUTE_OWNERSHIP_ACQUISITION,
    CANCEL_NEGOTIATED_ATTRIBUTE_OWNERSHIP_DIVESTITURE,
    ATTRIBUTE_OWNERSHIP_RELEASE_RESPONSE,
    CANCEL_ATTRIBUTE_OWNERSHIP_ACQUISITION,
    CONFIRM_ATTRIBUTE_OWNERSHIP_ACQUISITION_CANCELLATION,

    // Time
    CHANGE_ATTRIBUTE_ORDER_TYPE,
    CHANGE_INTERACTION_ORDER_TYPE,
    ENABLE_TIME_REGULATION,
    DISABLE_TIME_REGULATION,
    ENABLE_TIME_CONSTRAINED,
    DISABLE_TIME_CONSTRAINED,
    QUERY_LBTS,
    QUERY_FEDERATE_TIME,
    QUERY_MIN_NEXT_EVENT_TIME,
    MODIFY_LOOKAHEAD,
    QUERY_LOOKAHEAD,
    RETRACT,
    REQUEST_RETRACTION,
    TIME_ADVANCE_REQUEST,
    TIME_ADVANCE_REQUEST_AVAILABLE,
    NEXT_EVENT_REQUEST,
    NEXT_EVENT_REQUEST_AVAILABLE,
    FLUSH_QUEUE_REQUEST,
    TIME_ADVANCE_GRANT,
    ENABLE_ASYNCHRONOUS_DELIVERY,
    DISABLE_ASYNCHRONOUS_DELIVERY,
    TIME_REGULATION_ENABLED,
    TIME_CONSTRAINED_ENABLED,

    // Data Distribution Management
    DDM_CREATE_REGION,
    DDM_MODIFY_REGION,
    DDM_DELETE_REGION,
    DDM_REGISTER_OBJECT,
    DDM_ASSOCIATE_REGION,
    DDM_UNASSOCIATE_REGION,
    DDM_SUBSCRIBE_ATTRIBUTES,
    DDM_UNSUBSCRIBE_ATTRIBUTES,
    DDM_SUBSCRIBE_INTERACTION,
    DDM_UNSUBSCRIBE_INTERACTION,
    DDM_REQUEST_UPDATE,

    // Support Services
    GET_OBJECT_CLASS_HANDLE,
    GET_OBJECT_CLASS_NAME,
    GET_ATTRIBUTE_HANDLE,
    GET_ATTRIBUTE_NAME,
    GET_INTERACTION_CLASS_HANDLE,
    GET_INTERACTION_CLASS_NAME,
    GET_PARAMETER_HANDLE,
    GET_PARAMETER_NAME,
    GET_OBJECT_INSTANCE_HANDLE,
    GET_OBJECT_INSTANCE_NAME,
    GET_SPACE_HANDLE,
    GET_SPACE_NAME,
    GET_DIMENSION_HANDLE,
    GET_DIMENSION_NAME,
    GET_ATTRIBUTE_SPACE_HANDLE,
    GET_OBJECT_CLASS,
    GET_INTERACTION_SPACE_HANDLE,
    GET_TRANSPORTATION_HANDLE,
    GET_TRANSPORTATION_NAME,
    GET_ORDERING_HANDLE,
    GET_ORDERING_NAME,
    ENABLE_CLASS_RELEVANCE_ADVISORY_SWITCH,
    DISABLE_CLASS_RELEVANCE_ADVISORY_SWITCH,
    ENABLE_ATTRIBUTE_RELEVANCE_ADVISORY_SWITCH,
    DISABLE_ATTRIBUTE_RELEVANCE_ADVISORY_SWITCH,
    ENABLE_ATTRIBUTE_SCOPE_ADVISORY_SWITCH,
    DISABLE_ATTRIBUTE_SCOPE_ADVISORY_SWITCH,
    ENABLE_INTERACTION_RELEVANCE_ADVISORY_SWITCH,
    DISABLE_INTERACTION_RELEVANCE_ADVISORY_SWITCH,
    TICK_REQUEST,

    LAST; // should be the "last" (not used)
	
	/**<p>Makes a HashMap between the <code>int</code> which corresponds with the <code>Type</code> and the <code>Type</code> itself.</p>
	 * <p>For instance, <code>Type.reverseType.get(1)</code> will return the <code>Type</code> CREATE_FEDERATION_EXECUTION.</p>
	 */
	public static HashMap<Integer,Type> reverseType = new HashMap<Integer,Type> ();
	
	static {
        for (Type m : Type.values()) {
            reverseType.put(m.ordinal(), m);
        }
    }
	
	/**<p>Makes a HashMap between the <code>int</code> which corresponds with the <code>Type</code> and the <code>String</code> which corresponds with the <code>Type</code>.</p>
	 * <p>For instance, <code>Type.reverseString.get(n)</code> will return the <code>String</code> "CREATE_FEDERATION_EXECUTION".</p>
	 */
    public static HashMap<Integer,String> reverseString = new HashMap<Integer,String> ();

    static {
        for (Type m : Type.values()) {
            reverseString.put(m.ordinal(), m.toString());
        }
    }
	
    /**Returns the <code>int</code> which corresponds with the <code>Type</code>.
	 * @return the <code>int</code>
	 */
    public int getType(){
    	return this.ordinal();
    }
}
