package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>boolean</code>,
 * <code>tickTime</code>,
 * <code>tickTime</code>:
 * namely <code>MSG_Tick_Request</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class BooleanTickTimeTickTime {
	private boolean bool;
	private byte[] minTickTime;
	private byte[] maxTickTime;

	public  BooleanTickTimeTickTime(boolean bool, byte[] tickTime1, byte[] tickTime2) {
		this.bool = bool;
		this.minTickTime = tickTime1;
		this.maxTickTime = tickTime2;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>boolean</code>, <code>tickTime</code>, <code>tickTime</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		msgBuffer.write(this.bool, "boolean");
		msgBuffer.write(this.minTickTime, "minTickTime");
		msgBuffer.write(this.maxTickTime, "maxTickTime");
	}

	/**
	 * Reads the message from a buffer:
	 * <code>boolean</code>, <code>tickTime</code>, <code>tickTime</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer){
		this.bool = msgBuffer.readBoolean();
		this.minTickTime = msgBuffer.readBytes(8);
		this.maxTickTime = msgBuffer.readBytes(8);
	}

	/**
	 * @param bool the bool to set
	 */
	public void setBool(boolean bool) {
		this.bool = bool;
	}

	/**
	 * @param minTickTime the minTickTime to set
	 */
	public void setMinTickTime(byte[] minTickTime) {
		this.minTickTime = minTickTime;
	}

	/**
	 * @param maxTickTime the maxTickTime to set
	 */
	public void setMaxTickTime(byte[] maxTickTime) {
		this.maxTickTime = maxTickTime;
	}

	/**
	 * @return the bool
	 */
	public boolean isBool() {
		return bool;
	}

	/**
	 * @return the minTickTime
	 */
	public byte[] getMinTickTime() {
		return minTickTime;
	}

	/**
	 * @return the maxTickTime
	 */
	public byte[] getMaxTickTime() {
		return maxTickTime;
	}

}
