package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>federate</code>, <code>federationName</code>,
 * <code>federateName</code>:
 * namely <code>MSG_Join_Federation_Execution</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class FederateFederationNameFederateName {
	private short federate;
	private String federationName;
	private String federateName;

	public FederateFederationNameFederateName (short federate,
			String federationName, String federateName) {
		this.federate = federate;
		this.federationName = federationName;
		this.federateName = federateName;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>federate</code>, <code>federationName</code>, <code>federateName</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		msgBuffer.write(this.federate, "federate");
		msgBuffer.write(this.federationName, "federationName");
		msgBuffer.write(this.federateName, "federateName");
	}

	/**
	 * Reads the message from a buffer:
	 * <code>federate</code>, <code>federationName</code>, <code>federateName</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer){
		this.federate = msgBuffer.readShort();
		this.federationName = msgBuffer.readString();
		this.federateName = msgBuffer.readString();
	}

	/**
	 * @param federate the federate to set
	 */
	public void setFederate(short federate) {
		this.federate = federate;
	}

	/**
	 * @param federationName the federationName to set
	 */
	public void setFederationName(String federationName) {
		this.federationName = federationName;
	}

	/**
	 * @param federateName the federateName to set
	 */
	public void setFederateName(String federateName) {
		this.federateName = federateName;
	}

	/**
	 * @return the federate
	 */
	public short getFederate() {
		return federate;
	}

	/**
	 * @return the federationName
	 */
	public String getFederationName() {
		return federationName;
	}

	/**
	 * @return the federateName
	 */
	public String getFederateName() {
		return federateName;
	}

}
