package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>federationName</code> and <code>fedId</code>:
 * namely <code>MSG_Create_Federation_Execution</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class FederationNameFedId {
	private String federationName;
	private String fedId;

	public FederationNameFedId(String federationName, String fedId) {
		this.federationName = federationName;
		this.fedId = fedId;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>federationName</code>, <code>fedId</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		msgBuffer.write(this.federationName, "federationName");
		msgBuffer.write(this.fedId, "fedId");
	}

	/**
	 * Reads the message from a buffer:
	 * <code>federationName</code>, <code>fedId</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer){
		this.federationName = msgBuffer.readString();
		this.fedId = msgBuffer.readString();
	}

	/**
	 * @param federationName the federationName to set
	 */
	public void setFederationName(String federationName) {
		this.federationName = federationName;
	}

	/**
	 * @param did the fedId to set
	 */
	public void setFedId(String fedId) {
		this.fedId = fedId;
	}

	/**
	 * @return the federationName
	 */
	public String getFederationName() {
		return federationName;
	}

	/**
	 * @return the fedId
	 */
	public String getFedId() {
		return fedId;
	}

}
