package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>objectClass</code>:
 * namely <code>MSG_Unpublish_Object_Class</code>,
 * <code>MSG_Unsuscribe_Object_Class</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class ObjectClass {
	private long objectClass;

	public ObjectClass (long oClass) {
		this.objectClass = oClass;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>objectClass</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		msgBuffer.write(this.objectClass, "objectClass");
	}

	/**
	 * Reads the message from a buffer:
	 * <code>objectClass</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer){
		this.objectClass = msgBuffer.readLong();
	}

	/**
	 * @param objectClass the objectClass to set
	 */
	public void setObjectClass(long objectClass) {
		this.objectClass = objectClass;
	}

	/**
	 * @return the objectClass
	 */
	public long getObjectClass() {
		return objectClass;
	}

}
