package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>ObjectClass</code>,
 * <code>HandleArraySize</code>,
 * <code>HandleArray</code>:
 * namely <code>MSG_Publish_Object_Class</code>,
 * <code>MSG_Suscribe_Object_Class_Attributes</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class ObjectClassHandleArraySizeHandleArray {
	private long objectClass;
	private short handleArraySize;
	private byte[] handleArray;

	public ObjectClassHandleArraySizeHandleArray (long oClass,
			short hArraySize, byte[] hArray) {
		this.objectClass = oClass;
		this.handleArraySize = hArraySize;
		this.handleArray = hArray;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>objectClass</code>, <code>handleArraySize</code>, <code>handleArray</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		msgBuffer.write(this.objectClass, "objectClass");
		msgBuffer.write(this.handleArraySize, "handleArraySize");
		msgBuffer.write(this.handleArray, "handleArray");
	}

	/**
	 * Reads the message from a buffer:
	 * <code>objectClass</code>, <code>handleArraySize</code>, <code>handleArray</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer){
		this.objectClass = msgBuffer.readLong();
		this.handleArraySize = msgBuffer.readShort();
		this.handleArray = msgBuffer.readBytes(this.handleArraySize);
	}

	/**
	 * @param objectClass the objectClass to set
	 */
	public void setObjectClass(long objectClass) {
		this.objectClass = objectClass;
	}

	/**
	 * @param handleArraySize the handleArraySize to set
	 */
	public void setHandleArraySize(short handleArraySize) {
		this.handleArraySize = handleArraySize;
	}

	/**
	 * @param handleArray the handleArray to set
	 */
	public void setHandleArray(byte[] handleArray) {
		this.handleArray = handleArray;
	}

	/**
	 * @return the objectClass
	 */
	public long getObjectClass() {
		return objectClass;
	}

	/**
	 * @return the handleArraySize
	 */
	public short getHandleArraySize() {
		return handleArraySize;
	}

	/**
	 * @return the handleArray
	 */
	public byte[] getHandleArray() {
		return handleArray;
	}

}
