package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>objectClass</code>,
 * <code>handleArraySize</code>, <code>object</code>,
 * <code>tag</code>, <code>handleArray</code>,
 * <code>valueArray</code>, <code>resignAction</code>,
 * <code>boolean</code>:
 * namely <code>MSG_Update_Attribute_Values</code>,
 * <code>MSG_Reflect_Attribute_Values</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class ObjectClassHandleArraySizeObjectTagHandleArrayValueArrayResignActionBoolean {
	private long objectClass;
	private short handleArraySize;
	private long object;
	private String tag;
	private byte[] handleArray;
	private ValueArrayElement[] valueArray;
	private int resignAction;
	private boolean bool;

	public ObjectClassHandleArraySizeObjectTagHandleArrayValueArrayResignActionBoolean
			(long oClass, short hArrSize, long obj, String tag, byte[] hArr,
			ValueArrayElement[] valArr, int resAction, boolean bool) {
		this.objectClass = oClass;
		this.handleArraySize = hArrSize;
		this.object = obj;
		this.tag = tag;
		this.handleArray = hArr;
		this.valueArray = valArr;
		this.resignAction = resAction;
		this.bool = bool;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>objectClass</code>,<code>handleArraySize</code>,
	 * <code>object</code>,<code>tag</code>,
	 * <code>handleArray</code>,<code>valueArray</code>,
	 * <code>resignAction</code>,<code>boolean</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		int i;
		
		msgBuffer.write(this.objectClass, "objectClass");
		msgBuffer.write(this.handleArraySize, "handleArraySize");
		msgBuffer.write(this.object, "object");
		msgBuffer.write(this.tag, "tag");
		msgBuffer.write(this.handleArray, "handleArray");
		for (i=0; i<this.handleArraySize; i++) {
			msgBuffer.write(this.valueArray[i].getLength(),
					"valueArrayElement " + i + " length");
			msgBuffer.write(this.valueArray[i].getValue(),
					"valueArrayElement " + i + " value");
		}
		msgBuffer.write(this.resignAction, "resignAction");
		msgBuffer.write(this.bool, "boolean");
	}
	
	/**
	 * Reads the message from a buffer:
	 * <code>objectClass</code>,<code>handleArraySize</code>,
	 * <code>object</code>,<code>tag</code>,
	 * <code>handleArray</code>,<code>valueArray</code>,
	 * <code>resignAction</code>,<code>boolean</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer) {
		int i;
		
		this.objectClass = msgBuffer.readLong();
		this.handleArraySize = msgBuffer.readShort();
		this.object = msgBuffer.readLong();
		this.tag = msgBuffer.readString();
		this.handleArray = msgBuffer.readBytes(this.handleArraySize);
		this.valueArray = new ValueArrayElement[this.handleArraySize];
		for (i=0; i<this.handleArraySize; i++) {
			long length = msgBuffer.readLong();
			this.valueArray[i] = new ValueArrayElement(
					length, msgBuffer.readBytes((int)length));
		}
		this.resignAction = msgBuffer.readInt();
		this.bool = msgBuffer.readBoolean();
	}

	/**
	 * @param objectClass the objectClass to set
	 */
	public void setObjectClass(long objectClass) {
		this.objectClass = objectClass;
	}

	/**
	 * @param handleArraySize the handleArraySize to set
	 */
	public void setHandleArraySize(short handleArraySize) {
		this.handleArraySize = handleArraySize;
	}

	/**
	 * @param object the object to set
	 */
	public void setObject(long object) {
		this.object = object;
	}

	/**
	 * @param tag the tag to set
	 */
	public void setTag(String tag) {
		this.tag = tag;
	}

	/**
	 * @param handleArray the handleArray to set
	 */
	public void setHandleArray(byte[] handleArray) {
		this.handleArray = handleArray;
	}

	/**
	 * @param valueArray the valueArray to set
	 */
	public void setValueArray(ValueArrayElement[] valueArray) {
		this.valueArray = valueArray;
	}

	/**
	 * @param resignAction the resignAction to set
	 */
	public void setResignAction(int resignAction) {
		this.resignAction = resignAction;
	}

	/**
	 * @param bool the bool to set
	 */
	public void setBool(boolean bool) {
		this.bool = bool;
	}

	/**
	 * @return the objectClass
	 */
	public long getObjectClass() {
		return objectClass;
	}

	/**
	 * @return the handleArraySize
	 */
	public short getHandleArraySize() {
		return handleArraySize;
	}

	/**
	 * @return the object
	 */
	public long getObject() {
		return object;
	}

	/**
	 * @return the tag
	 */
	public String getTag() {
		return tag;
	}

	/**
	 * @return the handleArray
	 */
	public byte[] getHandleArray() {
		return handleArray;
	}

	/**
	 * @return the valueArray
	 */
	public ValueArrayElement[] getValueArray() {
		return valueArray;
	}

	/**
	 * @return the resignAction
	 */
	public int getResignAction() {
		return resignAction;
	}

	/**
	 * @return the bool
	 */
	public boolean isBool() {
		return bool;
	}

}
