package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>objectClass</code>, <code>name</code>,
 * <code>attribute</code>:
 * namely <code>MSG_Get_Object_Class_Handle</code>,
 * <code>MSG_Get_Object_Class_Name</code>,
 * <code>MSG_Get_Attribute_Handle</code>,
 * <code>MSG_Get_Attribute_Name</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class ObjectClassNameAttribute {
	private long objectClass;
	private String name;
	private short attribute;

	public ObjectClassNameAttribute (long oClass,
			String name, short attrib) {
		this.objectClass = oClass;
		this.name = name;
		this.attribute = attrib;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>objectClass</code>, <code>name</code>, <code>attribute</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		msgBuffer.write(this.objectClass, "objectClass");
		msgBuffer.write(this.name, "name");
		msgBuffer.write(this.attribute, "attribute");
	}

	/**
	 * Reads the message from a buffer:
	 * <code>objectClass</code>, <code>name</code>, <code>attribute</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer){
		this.objectClass = msgBuffer.readLong();
		this.name = msgBuffer.readString();
		this.attribute = msgBuffer.readShort();
	}

	/**
	 * @param objectClass the objectClass to set
	 */
	public void setObjectClass(long objectClass) {
		this.objectClass = objectClass;
	}

	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @param attribute the attribute to set
	 */
	public void setAttribute(short attribute) {
		this.attribute = attribute;
	}

	/**
	 * @return the objectClass
	 */
	public long getObjectClass() {
		return objectClass;
	}

	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @return the attribute
	 */
	public short getAttribute() {
		return attribute;
	}

}
