package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>objectClass</code>,
 * <code>object</code>,
 * <code>name</code>:
 * namely <code>MSG_Register_Object_Instance</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class ObjectClassObjectName {
	private long objectClass;
	private long object;
	private String name;

	public ObjectClassObjectName (long oClass,
			long obj, String name) {
		this.objectClass = oClass;
		this.object = obj;
		this.name = name;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>objectClass</code>, <code>object</code>, <code>name</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		msgBuffer.write(this.objectClass, "objectClass");
		msgBuffer.write(this.object, "object");
		msgBuffer.write(this.name, "name");
	}

	/**
	 * Reads the message from a buffer:
	 * <code>objectClass</code>, <code>object</code>, <code>name</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer){
		this.objectClass = msgBuffer.readLong();
		this.object = msgBuffer.readLong();
		this.name = msgBuffer.readString();
	}

	/**
	 * @param objectClass the objectClass to set
	 */
	public void setObjectClass(long objectClass) {
		this.objectClass = objectClass;
	}

	/**
	 * @param object the object to set
	 */
	public void setObject(long object) {
		this.object = object;
	}

	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the objectClass
	 */
	public long getObjectClass() {
		return objectClass;
	}

	/**
	 * @return the object
	 */
	public long getObject() {
		return object;
	}

	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}

}
