package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>objectClass</code>,
 * <code>object</code>, <code>tag</code>, <code>name</code>,
 * <code>label</code>, <code>resignAction</code>, <code>boolean</code>:
 * namely <code>MSG_Delete_Object_Instance</code>,
 * <code>MSG_Remove_Object_Instance</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class ObjectClassObjectTagNameLabelResignActionBoolean {
	private long objectClass;
	private long object;
	private String tag;
	private String name;
	private String label;
	private int resignAction;
	private boolean bool;

	public ObjectClassObjectTagNameLabelResignActionBoolean (long oClass, long obj,
			String tag, String name, String lab, int resAction , boolean bool) {
		this.objectClass = oClass;
		this.object = obj;
		this.tag = tag;
		this.name = name;
		this.label = lab;
		this.resignAction = resAction;
		this.bool = bool;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>object</code>, <code>tag</code>, <code>name</code>,
	 * <code>label</code>, <code>resignAction</code>, <code>boolean</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		msgBuffer.write(this.objectClass, "objectClass");
		msgBuffer.write(this.object, "object");
		msgBuffer.write(this.tag, "tag");
		msgBuffer.write(this.name, "name");
		msgBuffer.write(this.label, "label");
		msgBuffer.write(this.resignAction, "resignAction");
		msgBuffer.write(this.bool, "boolean");
	}

	/**
	 * Reads the message from a buffer:
	 * <code>object</code>, <code>tag</code>, <code>name</code>,
	 * <code>label</code>, <code>resignAction</code>, <code>boolean</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer){
		this.objectClass = msgBuffer.readLong();
		this.object = msgBuffer.readLong();
		this.tag = msgBuffer.readString();
		this.name = msgBuffer.readString();
		this.label = msgBuffer.readString();
		this.resignAction = msgBuffer.readInt();
		this.bool = msgBuffer.readBoolean();
	}

	/**
	 * @param objectClass the objectClass to set
	 */
	public void setObjectClass(long objectClass) {
		this.objectClass = objectClass;
	}

	/**
	 * @param object the object to set
	 */
	public void setObject(long object) {
		this.object = object;
	}

	/**
	 * @param tag the tag to set
	 */
	public void setTag(String tag) {
		this.tag = tag;
	}

	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @param label the label to set
	 */
	public void setLabel(String label) {
		this.label = label;
	}

	/**
	 * @param resignAction the resignAction to set
	 */
	public void setResignAction(int resignAction) {
		this.resignAction = resignAction;
	}

	/**
	 * @param bool the bool to set
	 */
	public void setBool(boolean bool) {
		this.bool = bool;
	}

	/**
	 * @return the objectClass
	 */
	public long getObjectClass() {
		return objectClass;
	}

	/**
	 * @return the object
	 */
	public long getObject() {
		return object;
	}

	/**
	 * @return the tag
	 */
	public String getTag() {
		return tag;
	}

	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * @return the label
	 */
	public String getLabel() {
		return label;
	}

	/**
	 * @return the resignAction
	 */
	public int getResignAction() {
		return resignAction;
	}

	/**
	 * @return the bool
	 */
	public boolean isBool() {
		return bool;
	}

}
