package message.content;

import message.MessageBuffer;

/**
 * Treatment of messages containing <code>object</code>, <code>name</code>:
 * namely <code>MSG_Get_Object_Instance_Handle</code>,
 * <code>MSG_Get_Object_Instance_Name</code>.
 * 
* @author <a href = "mailto:yannick.bisiaux@supaero.fr">Yannick Bisiaux</a>, <a href = "mailto:ronan.bossard@supaero.fr">Ronan Bossard</a>, <a href = "mailto:samuel.reese@supaero.fr">Samuel Reese</a>
* @version 1.0
 *
 */
public class ObjectName {
	private long object;
	private String name;

	public ObjectName (long obj, String nam) {
		this.object = obj;
		this.name = nam;
	}

	/**
	 * Writes the message to a buffer:
	 * <code>object</code>, <code>name</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * to which the message is written.
	 */
	public void writeObject(MessageBuffer msgBuffer){
		msgBuffer.write(this.object, "object");
		msgBuffer.write(this.name, "name");
	}

	/**
	 * Reads the message from a buffer:
	 * <code>object</code>, <code>name</code>.
	 * 
	 * @param msgBuffer the <code>MessageBuffer</code>
	 * from which the message is read.
	 */
	public void readObject(MessageBuffer msgBuffer){
		this.object = msgBuffer.readLong();
		this.name = msgBuffer.readString();
	}

	/**
	 * @param object the object to set
	 */
	public void setObject(long object) {
		this.object = object;
	}

	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the object
	 */
	public long getObject() {
		return object;
	}

	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}

}
